@@ -32,7 +32,6 @@ Here is a minimal deployable pattern definition:
 const { DynamoDBStreamToLambdaToElasticSearchAndKibana, DynamoDBStreamToLambdaToElasticSearchAndKibanaProps } = require('@aws-solutions-constructs/aws-dynamodb-stream-lambda-elasticsearch-kibana');
 
 const props: DynamoDBStreamToLambdaToElasticSearchAndKibanaProps = {
-    deployLambda: true,
     lambdaFunctionProps: {
         code: lambda.Code.asset(`${__dirname}/lambda`),
         runtime: lambda.Runtime.NODEJS_12_X,
@@ -60,9 +59,8 @@ new DynamoDBStreamToLambdaToElasticSearchAndKibana(scope: Construct, id: string,
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|deployLambda|`boolean`|Whether to create a new Lambda function or use an existing Lambda function|
-|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object|
-|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|Optional user provided props to override the default props for Lambda function|
+|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.|
+|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|User provided props to override the default props for the Lambda function.|
 |dynamoTableProps?|[`dynamodb.TableProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-dynamodb.TableProps.html)|Optional user provided props to override the default props for DynamoDB Table|
 |existingTableObj?|[`dynamodb.Table`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-dynamodb.Table.html)|Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored|
 |dynamoEventSourceProps?|[`aws-lambda-event-sources.DynamoEventSourceProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda-event-sources.DynamoEventSourceProps.html)|Optional user provided props to override the default props for DynamoDB Event Source|
@@ -150,7 +148,6 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibana(
         scope: aws_cdk.core.Construct,
         id: str,
         *,
-        deploy_lambda: bool,
         domain_name: str,
         dynamo_event_source_props: typing.Optional[
             aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps
@@ -166,14 +163,13 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibana(
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
-        :param deploy_lambda: Whether to create a new lambda function or use an existing lambda function. If set to false, you must provide a lambda function object as ``existingObj`` Default: - true
         :param domain_name: Cognito & ES Domain Name. Default: - None
         :param dynamo_event_source_props: Optional user provided props to override the default props. Default: - Default props are used
         :param dynamo_table_props: Optional user provided props to override the default props. Default: - Default props are used
         :param es_domain_props: Optional user provided props to override the default props for the API Gateway. Default: - Default props are used
-        :param existing_lambda_obj: Existing instance of Lambda Function object. If ``deploy`` is set to false only then this property is required Default: - None
+        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
         :param existing_table_obj: Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored. Default: - None
-        :param lambda_function_props: Optional user provided props to override the default props. If ``deploy`` is set to true only then this property is required Default: - Default props are used
+        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
 
         access:
         :access:: public
@@ -183,7 +179,6 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibana(
         :summary:: Constructs a new instance of the LambdaToDynamoDB class.
         """
         props = DynamoDBStreamToLambdaToElasticSearchAndKibanaProps(
-            deploy_lambda=deploy_lambda,
             domain_name=domain_name,
             dynamo_event_source_props=dynamo_event_source_props,
             dynamo_table_props=dynamo_table_props,
@@ -237,7 +232,6 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibana(
     jsii_type="@aws-solutions-constructs/aws-dynamodb-stream-lambda-elasticsearch-kibana.DynamoDBStreamToLambdaToElasticSearchAndKibanaProps",
     jsii_struct_bases=[],
     name_mapping={
-        "deploy_lambda": "deployLambda",
         "domain_name": "domainName",
         "dynamo_event_source_props": "dynamoEventSourceProps",
         "dynamo_table_props": "dynamoTableProps",
@@ -251,7 +245,6 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps:
     def __init__(
         self,
         *,
-        deploy_lambda: bool,
         domain_name: str,
         dynamo_event_source_props: typing.Optional[
             aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps
@@ -265,14 +258,13 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps:
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
     ) -> None:
         """
-        :param deploy_lambda: Whether to create a new lambda function or use an existing lambda function. If set to false, you must provide a lambda function object as ``existingObj`` Default: - true
         :param domain_name: Cognito & ES Domain Name. Default: - None
         :param dynamo_event_source_props: Optional user provided props to override the default props. Default: - Default props are used
         :param dynamo_table_props: Optional user provided props to override the default props. Default: - Default props are used
         :param es_domain_props: Optional user provided props to override the default props for the API Gateway. Default: - Default props are used
-        :param existing_lambda_obj: Existing instance of Lambda Function object. If ``deploy`` is set to false only then this property is required Default: - None
+        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
         :param existing_table_obj: Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored. Default: - None
-        :param lambda_function_props: Optional user provided props to override the default props. If ``deploy`` is set to true only then this property is required Default: - Default props are used
+        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
 
         summary:
         :summary:: The properties for the DynamoDBStreamToLambdaToElastciSearchAndKibana Construct
@@ -292,7 +284,6 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps:
                 **lambda_function_props
             )
         self._values = {
-            "deploy_lambda": deploy_lambda,
             "domain_name": domain_name,
         }
         if dynamo_event_source_props is not None:
@@ -308,17 +299,6 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps:
         if lambda_function_props is not None:
             self._values["lambda_function_props"] = lambda_function_props
 
-    @builtins.property
-    def deploy_lambda(self) -> bool:
-        """Whether to create a new lambda function or use an existing lambda function.
-
-        If set to false, you must provide a lambda function object as ``existingObj``
-
-        default
-        :default: - true
-        """
-        return self._values.get("deploy_lambda")
-
     @builtins.property
     def domain_name(self) -> str:
         """Cognito & ES Domain Name.
@@ -361,9 +341,7 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps:
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
-        """Existing instance of Lambda Function object.
-
-        If ``deploy`` is set to false only then this property is required
+        """Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
 
         default
         :default: - None
@@ -383,9 +361,7 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps:
     def lambda_function_props(
         self,
     ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
-        """Optional user provided props to override the default props.
-
-        If ``deploy`` is set to true only then this property is required
+        """User provided props to override the default props for the Lambda function.
 
         default
         :default: - Default props are used
